#
# spec file for package setools
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}

# doesn't work for python 2
%define skip_python2 1

Name:           setools
Version:        4.2.2
Release:        1.19
Url:            https://github.com/SELinuxProject/setools
Summary:        Policy analysis tools for SELinux
License:        GPL-2.0-only
Group:          System/Management
Source:         https://github.com/SELinuxProject/setools/archive/%{version}.tar.gz
# PATCH-FIX-UPSTREAM python3.8-compat.patch mcepl@suse.com
# allow build with Python 3.8
Patch0:         python3.8-compat.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  libselinux-devel
BuildRequires:  libsepol-devel
BuildRequires:  python-rpm-macros
BuildRequires:  swig
Requires:       setools-console = %{version}-%{release}
Requires:       setools-gui = %{version}-%{release}

%description
SETools is a collection of graphical tools, command-line tools, and
libraries designed to facilitate SELinux policy analysis.

This meta-package depends upon the main packages necessary to run
SETools.

%package console
Summary:        Policy analysis command-line tools for SELinux
License:        GPL-2.0-only
Group:          System/Base
Requires:       python3-setools = %{version}

%description console
SETools is a collection of graphical tools, command-line tools, and
libraries designed to facilitate SELinux policy analysis.

This package includes the following console tools:

  seinfo          Provide information about policies
  sesearch        Tool to query policies
  sedta           Domain transition analysis tool
  seinfoflow      Information flow analysis tool
  sediff          Semantic policy difference tool

%package -n python3-setools
Summary:        Python bindings for SELinux policy analysis
License:        LGPL-2.0-only
Group:          Development/Languages/Python
Requires:       python
Obsoletes:      python-setools < %{version}
Provides:       python-setools = %{version}-%{release}

%description -n python3-setools
SETools is a collection of graphical tools, command-line tools, and
libraries designed to facilitate SELinux policy analysis.

%package gui
Summary:        Policy analysis graphical tools for SELinux
License:        GPL-2.0-only
Group:          System/Base
Requires:       bwidget
Requires:       gtk2
Requires:       tcl
Requires:       tk

%description gui
SETools is a collection of graphical tools, command-line tools, and
libraries designed to facilitate SELinux policy analysis.

This package includes the following graphical tools:

  apol          policy analysis tool

%prep
%setup -q -n %{name}-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%fdupes -s %{buildroot}%{python3_sitearch}

%files -n python3-setools
%defattr(-,root,root,-)
%dir %{python3_sitearch}/setools/
%{python3_sitearch}/setools/*
%{python3_sitearch}/setools*egg-info*

%files console
%defattr(-,root,root,-)
%{_bindir}/seinfo
%{_bindir}/sesearch
%{_bindir}/sedta
%{_bindir}/seinfoflow
%{_bindir}/sediff
%{_mandir}/man1/sedta.1.gz
%{_mandir}/man1/seinfoflow.1.gz
%{_mandir}/man1/sediff.1.gz
%{_mandir}/man1/seinfo.1.gz
%{_mandir}/man1/sesearch.1.gz

%files gui
%defattr(-,root,root,-)
%{python3_sitearch}/setoolsgui*
%{_bindir}/apol
%{_mandir}/man1/apol.1.gz

%changelog
* Thu Oct 31 2019 mcepl@suse.com
- Add python3.8-compat.patch to allow build with Python 3.8
  Still doesn't work though because of gh#SELinuxProject/setools#31
* Thu Oct 31 2019 mcepl@suse.com
- Update to the upstream version 4.2.2:
  - Remove source policy references from man pages, as loading
    source policies is no longer supported.
  - Fixed a performance regression in alias loading after alias
    dereferencing fixes in 4.2.1.
* Tue Feb  5 2019 jsegitz@suse.com
- Update to 4.2.1
  * Set SIGPIPE handler for CLI tools.
  * Fixed alias dereferencing in TypeQuery and type, category, and
    sensitivity lookups.
  * Fixed sediff bug for rendering modified nodecons.
  * Fixed devicetreecon count output.
  * Fixed policy target platform check.
  * Fixed bug in creating permission set intersection in apol.
- Provide python-setools
* Fri Dec  7 2018 jsegitz@suse.com
- Changed requires of console subpackage to python3-setools
* Wed Nov 21 2018 jsegitz@suse.com
- Upgrade to 4.2.0
  * Support for Python 2.7 was dropped
  * Symbol names are now available as the name attribute (e.g. Boolean.name, Type.name, etc.)
  * Move constraint expression to its own class.
  * Made Conditional.evaluate() more useful and added BaseTERule.enabled() method to determine if a rule is enabled..
  * Added support for SCTP portcons
  * Updated permission maps
- Dropped warning.patch
- Single spec, limited to python3. Obsoletes python-setools, provides
  python3-setools
* Mon Jun 11 2018 jsegitz@suse.com
- Added warning.patch in former change to prevent warnings from
  stopping the build
* Wed May 16 2018 mcepl@suse.com
- Upgrade to 4.1.1
* Wed Dec 20 2017 jsegitz@suse.com
- Update to version 4.0.1. SETools was reimplemented in Python.
- Doesn't build
  * setools-libs
  * setools-java
  * setools-tcl
  * setools-devel
  anymore since the files are not povided anymore
- Dropped
  * add-to-header-define_cond_filename_trans.patch
  * implicit-fortify-decl.patch
  * setools-3.3.5-javacflags.patch
  * setools-3.3.5-nonvoid.patch
  * setools-3.3.5-strcmp.patch
  * setools-am121.patch
  * setools-libsepol.patch
  * setools-setup_py-prefix.patch
  * setools-swig-2.0.7.patch
  * setools-swig-2x.patch
  * setools-tclass.patch
* Sat Sep 30 2017 coolo@suse.com
- Move to minimum java target of 1.6, 1.5 is no longer supported
* Mon Jun 26 2017 jsegitz@suse.com
- Added implicit-fortify-decl.patch to prevent warnings about implicit
  declarations
* Thu Aug 25 2016 jsegitz@novell.com
- Deleted setools-3.3.7-libselinux-2.3.patch, we have a
  current libselinux now
* Mon Jul 18 2016 jsegitz@novell.com
- Patch to work with current libsepol, libselinux
  Added: setools-tclass.patch
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 3.3.8
  * Fix bug preventing seaudit from starting
  * Add python bindings for seinfo and sesearch
  * seinfo exits with an error status
  * Support for named file transition rules
  * Add support for default types in sesearch
  * Man page updates for seinfo, seaudit, and sediff
  * Fix file type drop down list for open/close Apol query
  * Fix compile errors on new parameter in libsepol role_set_expand().
- Update home project and download Urls
- Remove merged patches
  * setools-python.patch
  * 0003-Since-we-do-not-ship-neverallow-rules-all-always-fai.patch
  * 0006-Changes-to-support-named-file_trans-rules.patch
  * 0007-Remove-unused-variables.patch
- Update setools-3.3.6-libsepol.patch > setools-libsepol.patch
- Remove redundant %%clean section
* Mon May 26 2014 ro@suse.de
- add patch: setools-3.3.7-libselinux-2.3.patch
  fix build with libselinux-2.3
* Fri Oct 11 2013 vcizek@suse.com
- don't fail if there are no never-allow rules in the policy
- remove dangling symlink /usr/bin/seaudit (bnc#812285)
  * added 0003-Since-we-do-not-ship-neverallow-rules-all-always-fai.patch
* Fri Sep 13 2013 pgajdos@suse.com
- javapackages-tools in buildrequires
* Tue Mar 12 2013 vcizek@suse.com
- added patches:
  * 0006-Changes-to-support-named-file_trans-rules.patch
  * 0007-Remove-unused-variables.patch
  - these two add support for named file trans rules
  * add-to-header-define_cond_filename_trans.patch
  - add missing define_cond_filename_trans() declaration
* Thu Oct 25 2012 coolo@suse.com
- add explicit buildrequire on libbz2-devel
* Tue Aug 28 2012 idonmez@suse.com
- Add setools-3.3.6-libsepol.patch to fix compilation with new
  libsepol
* Sun Aug  5 2012 meissner@suse.com
- updated to version 3.3.7
- removed 2 upstream patches
* Tue Jul  3 2012 coolo@suse.com
- add setools-am121.patch to fix build with automake 1.12.1
* Thu Jun 14 2012 mls@suse.de
- fix build with swig-2.0.7 (untested, though)
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu May 26 2011 idonmez@novell.com
- Add setools-swig-2x.patch: correctly detect swig 2.x
* Thu Feb 25 2010 prusnak@suse.cz
- updated to 3.3.6
* Sat Sep  5 2009 dmueller@suse.de
- remove libselinux requires, it does not exist and
  autorequires will do the right thing anyway
* Wed Jul 15 2009 prusnak@suse.cz
- disable Requires: usermode
* Tue Jun 23 2009 prusnak@suse.cz
- require libsepol-devel-static
* Mon Oct 20 2008 prusnak@suse.cz
- disable Python for now (weird glibc errors)
* Tue Sep  2 2008 prusnak@suse.cz
- updated to 3.3.5
  * Fixed errors in libapol's AV and TE rule rendering functions
    where errno was not being set properly.
  * Fixed error in apol_syn_avrule_render() where braces were
    not being added around the target set when there is exactly one
    target type and the keyword 'self'.  Thanks to Ryan Kagin
    for reporting this error.
  * Added qpol_type_get_ispermissive(). SETools can now handle
    version 23 policy.
* Thu Jul 17 2008 prusnak@suse.cz
- initial version 3.3.4
  * based on Fedora package by Dan Walsh <dwalsh@redhat.com>
